@@ -44,7 +44,6 @@ public:
     void dbg_alwaysFailDialing(bool set = true);
 
     QString getSelfNumber();
-
     void cancel(AsyncTaskToken *token);
 
     static void
@@ -79,6 +78,9 @@ signals:
     //! Emitted by the nw class to give updates about the current progress
     void sigProgress(double percent);
 
+public slots:
+    void resetNwMgr();
+
 private slots:
 
     // Login and two factor
@@ -171,7 +173,7 @@ private:
     //! The users Google Voice number
     QString strSelfNumber;
 
-    QNetworkAccessManager nwMgr;
+    QNetworkAccessManager *nwMgr;
     CookieJar *jar;
     QVariantMap hiddenLoginFields;
 
