@@ -1,6 +1,6 @@
 /*
 qgvdial is a cross platform Google Voice Dialer
-Copyright (C) 2010  Yuvraaj Kelkar
+Copyright (C) 2009-2012  Yuvraaj Kelkar
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -54,10 +54,12 @@ public:
     bool refresh ();
 
     bool insertEntry (const GVInboxEntry &hEvent);
+    bool deleteEntry (const GVInboxEntry &hEvent);
     bool markAsRead (const QString &msgId);
 
 private:
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
+    bool searchById(const QString &id, quint32 &foundRow);
 
     QString strSelectType;
     GVI_Entry_Type eSelectType;
