@@ -1,6 +1,6 @@
 /*
 qgvdial is a cross platform Google Voice Dialer
-Copyright (C) 2010  Yuvraaj Kelkar
+Copyright (C) 2009-2012  Yuvraaj Kelkar
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -42,7 +42,11 @@ enum {
 #endif
 
 MainApp::MainApp (int &argc, char **argv)
+#if HAS_SINGLE_APP
 : QtSingleApplication (argc, argv)
+#else
+: QApplication (argc, argv)
+#endif
 {
 #ifdef Q_WS_WIN32
     uidDiscover  = RegisterWindowMessageA ("SkypeControlAPIDiscover");
