@@ -108,10 +108,12 @@ MainWindow::MainWindow (QWidget *parent)
         pSystray->show ();
     }
 
+#if HAS_SINGLE_APP
     rv = connect (qApp, SIGNAL (messageReceived(const QString &)),
                   this, SLOT   (messageReceived(const QString &)));
-    Q_ASSERT(rv);
+    // This *may* fail
     if (!rv) { exit(1); }
+#endif
 
     rv = connect (&statusTimer, SIGNAL (timeout()),
                    this       , SLOT   (onStatusTimerTick ()));
@@ -241,13 +243,30 @@ MainWindow::init ()
 
     // Initialize the DBUS interface to allow other applications (and qgv-tp) to
     // initiate calls and send texts through us.
-    osd.initDialServer (this, SLOT (dialNow (const QString &)));
-    osd.initTextServer (
-        this, SLOT (sendSMS (const QStringList &, const QString &)),
-        this, SLOT (onSendTextWithoutData (const QStringList &)));
-    osd.initSettingsServer (
-        this, SLOT(onRegPhoneSelectionChange(int)),
-        this, SIGNAL(regPhoneChange(const QStringList &,int)));
+    osd.initApiServer ();
+
+    // Connect the externally visible signals
+    rv = connect (&osd, SIGNAL(dialNow(const QString &)),
+                  this, SLOT(dialNow(const QString &)));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (&osd,
+                  SIGNAL(sendText(const QStringList &,const QString &)),
+                  this, SLOT(sendSMS(const QStringList &,const QString &)));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (&osd, SIGNAL(sendTextWithoutData(const QStringList &)),
+                  this, SLOT(onSendTextWithoutData (const QStringList &)));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (&osd, SIGNAL(phoneIndexChange(int)),
+                  this, SLOT(onRegPhoneSelectionChange(int)));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+    rv = connect (this, SIGNAL(regPhoneChange(const QStringList &,int)),
+                  &osd, SIGNAL(phoneChanges(const QStringList &,int)));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
 
     // Set up cookies
     QList<QNetworkCookie> cookies;
@@ -418,6 +437,13 @@ MainWindow::init ()
     if (!rv) { exit(1); }
 #endif
 
+    // When there is a real change in the NW configuration, reset the nw access
+    // manager on the GvAPI class object
+    rv = connect(&Singletons::getRef().getNwInfo(), SIGNAL(realChange()),
+                 &gvApi, SLOT(resetNwMgr()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+
     // If the cache has the username and password, begin login
     if (dbMain.getUserPass (strUser, strPass)) {
         this->setUsername (strUser);
@@ -891,17 +917,22 @@ MainWindow::gotAllRegisteredPhones (AsyncTaskToken *token)
 void
 MainWindow::onRegPhoneSelectionChange (int index)
 {
+    CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
+    if (index > modelRegNumber->rowCount()) {
+        Q_WARN("Attempting to go out of bounds on the registered phones");
+        return;
+    }
+
+    indRegPhone = index;
+
     QObject *regView = getQMLObject ("RegisteredPhonesView");
     Q_ASSERT(regView);
     QMetaObject::invokeMethod (regView, "setSelected", Q_ARG(QVariant, index));
 
-    indRegPhone = index;
-
-    CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
-    dbMain.putCallback (QString("%1").arg (indRegPhone));
+    dbMain.putCallback (QString("%1").arg (index));
 
     RegNumData data;
-    if (!modelRegNumber->getAt (indRegPhone, data)) {
+    if (!modelRegNumber->getAt (index, data)) {
         data.strName = "<Unknown>";
     }
 
@@ -1374,7 +1405,8 @@ MainWindow::getQMLObject(const char *pageName)
     do { // Begin cleanup block (not a loop)
         QObject *pRoot = this->rootObject ();
         if (NULL == pRoot) {
-            Q_WARN("Couldn't get root object in QML for ") << pageName;
+            Q_WARN(QString("Couldn't get root object in QML for %1")
+                    .arg(pageName));
             break;
         }
 
@@ -1385,7 +1417,7 @@ MainWindow::getQMLObject(const char *pageName)
 
         pObj = pRoot->findChild <QObject*> (pageName);
         if (NULL == pObj) {
-            Q_WARN("Could not get to ") << pageName;
+            Q_WARN(QString("Could not find page %1").arg (pageName));
             break;
         }
     } while (0); // End cleanup block (not a loop)
