@@ -21,11 +21,14 @@ Contact: yuvraaj@gmail.com
 
 #include "OsDependent.h"
 
+OsDependent::OsDependent(QObject *parent)
+: QObject(parent)
+, bDBusObjectRegistered(false)
 #if TELEPATHY_CAPABLE
-#include "QGVDbusServer.h"
+, dbusCallApi(NULL)
+, dbusTextApi(NULL)
+, dbusSettingsApi(NULL)
 #endif
-
-OsDependent::OsDependent(QObject *parent) : QObject(parent)
 {
 #if SYSTEMDISPLAYINFO
     displayInfo = NULL;
@@ -96,7 +99,7 @@ bool
 OsDependent::isSymbian1()
 {
     bool rv = false;
-#if defined(Q_OS_SYMBIAN)
+#if defined(IS_S1)
     QSysInfo::SymbianVersion symVer = QSysInfo::symbianVersion();
     rv = (symVer == QSysInfo::SV_SF_1);
 #endif
@@ -107,84 +110,136 @@ bool
 OsDependent::isSymbian3()
 {
     bool rv = false;
-#if defined(Q_OS_SYMBIAN)
-    QSysInfo::SymbianVersion symVer = QSysInfo::symbianVersion();
-    rv = (symVer == QSysInfo::SV_SF_3);
+#if defined(IS_S3) || defined(IS_S3_BELLE)
+//    QSysInfo::SymbianVersion symVer = QSysInfo::symbianVersion();
+//    rv = (symVer == QSysInfo::SV_SF_3);
+    rv = true;
 #endif
     return (rv);
 }//OsDependent::isSymbian3
 
-void
-OsDependent::initDialServer (QObject *receiver, const char *method)
+bool
+OsDependent::ensureDBusObject()
 {
 #if TELEPATHY_CAPABLE
-    static QGVDbusCallServer *pDialServer = NULL;
-    if (NULL == pDialServer) {
-        pDialServer = new QGVDbusCallServer (this);
-        pDialServer->addCallReceiver (receiver, method);
-
+    if (!bDBusObjectRegistered) {
         QDBusConnection sessionBus = QDBusConnection::sessionBus();
-        if (!sessionBus.registerObject ("/org/QGVDial/CallServer", this) ||
-            !sessionBus.registerService("org.QGVDial.CallServer")) {
-            qWarning ("Failed to register Dbus Call server. Aborting!");
-            qApp->quit ();
-        }
-    }
-#else
-    Q_UNUSED (receiver);
-    Q_UNUSED (method);
-#endif
-}//OsDependent::initDialServer
-
-void
-OsDependent::initTextServer (QObject *r1, const char *m1,
-                             QObject *r2, const char *m2)
-{
-#if TELEPATHY_CAPABLE
-    static QGVDbusTextServer *pTextServer = NULL;
-    if (NULL == pTextServer) {
-        pTextServer = new QGVDbusTextServer (this);
-        pTextServer->addTextReceivers (r1, m1, r2, m2);
-
-        QDBusConnection sessionBus = QDBusConnection::sessionBus();
-        if (!sessionBus.registerObject ("/org/QGVDial/TextServer", this) ||
-            !sessionBus.registerService("org.QGVDial.TextServer")) {
-            qWarning ("Failed to register Dbus Text server. Aborting!");
-            qApp->quit ();
-        }
-    }
-#else
-    Q_UNUSED (r1);
-    Q_UNUSED (m1);
-    Q_UNUSED (r2);
-    Q_UNUSED (m2);
-#endif
-}//OsDependent::initDialServer
-
-void
-OsDependent::initSettingsServer(QObject *r1, const char *m1,
-                                QObject *r2, const char *m2)
-{
-#if TELEPATHY_CAPABLE
-    static QGVDbusSettingsServer *pServer = NULL;
-    if (NULL == pServer) {
-        pServer = new QGVDbusSettingsServer (this);
-        pServer->addSettingsReceiver (r1, m1, r2, m2);
-
-        QDBusConnection sessionBus = QDBusConnection::sessionBus();
-        if (!sessionBus.registerObject ("/org/QGVDial/SettingsServer", this) ||
-            !sessionBus.registerService("org.QGVDial.SettingsServer")) {
+        if (!sessionBus.registerService("org.QGVDial.APIServer")) {
             qWarning ("Failed to register Dbus Settings server. Aborting!");
             qApp->quit ();
         }
+
+        bDBusObjectRegistered = true;
     }
-#else
-    Q_UNUSED (r1);
-    Q_UNUSED (m1);
-    Q_UNUSED (r2);
-    Q_UNUSED (m2);
+
 #endif
-}
+    return bDBusObjectRegistered;
+}//OsDependent::ensureDBusObject
+
+void
+OsDependent::initApiServer()
+{
+#if TELEPATHY_CAPABLE
+    if (!ensureDBusObject ()) {
+        Q_WARN("Failed to register Dbus API server. Aborting!");
+        qApp->quit ();
+        return;
+    }
+
+    bool rv = false;
+    do {
+        if (NULL == dbusCallApi) {
+            dbusCallApi = new QGVDBusCallApi(this);
+            if (NULL == dbusCallApi) {
+                Q_WARN("Couldn't allocate call api");
+                break;
+            }
+            if (!dbusCallApi->registerObject ()) {
+                Q_WARN("Failed to register call api");
+                break;
+            }
+            rv = connect(dbusCallApi, SIGNAL(dialNow(const QString &)),
+                         this, SIGNAL(dialNow(const QString &)));
+            if (!rv) {
+                Q_WARN("Failed to connect call signal");
+                break;
+            }
+            rv = false;
+        }
+
+        if (NULL == dbusTextApi) {
+            dbusTextApi = new QGVDBusTextApi(this);
+            if (NULL == dbusTextApi) {
+                Q_WARN("Couldn't allocate text api");
+                break;
+            }
+            if (!dbusTextApi->registerObject ()) {
+                Q_WARN("Failed to register text api");
+                break;
+            }
+            rv = connect(dbusTextApi,
+                         SIGNAL(sendText(const QStringList&,const QString&)),
+                         this,
+                         SIGNAL(sendText(const QStringList&,const QString&)));
+            if (!rv) {
+                Q_WARN("Failed to connect text signal");
+                break;
+            }
+            rv = connect(dbusTextApi,
+                         SIGNAL(sendTextWithoutData(const QStringList&)),
+                         this, SIGNAL(sendTextWithoutData(const QStringList&)));
+            if (!rv) {
+                Q_WARN("Failed to connect second text signal");
+                break;
+            }
+            rv = false;
+        }
+
+        if (NULL == dbusSettingsApi) {
+            dbusSettingsApi = new QGVDBusSettingsApi(this);
+            if (NULL == dbusSettingsApi) {
+                Q_WARN("Couldn't allocate text api");
+                break;
+            }
+            if (!dbusSettingsApi->registerObject ()) {
+                Q_WARN("Failed to register settings api");
+                break;
+            }
+            rv = connect(dbusSettingsApi, SIGNAL(phoneIndexChange(int)),
+                         this, SIGNAL(phoneIndexChange(int)));
+            if (!rv) {
+                Q_WARN("Failed to connect second text signal");
+                break;
+            }
+            rv = connect(this, SIGNAL(phoneChanges(const QStringList&,int)),
+                         dbusSettingsApi,
+                         SLOT(onPhoneChanges(const QStringList&,int)));
+            if (!rv) {
+                Q_WARN("Failed to connect second text signal");
+                break;
+            }
+            rv = false;
+        }
+
+        rv = true;
+    } while(0);
+
+    if (!rv) {
+        if (NULL != dbusCallApi) {
+            delete dbusCallApi;
+            dbusCallApi = NULL;
+        }
+        if (NULL != dbusTextApi) {
+            delete dbusTextApi;
+            dbusTextApi = NULL;
+        }
+        if (NULL != dbusSettingsApi) {
+            delete dbusSettingsApi;
+            dbusSettingsApi = NULL;
+        }
+    }
+#endif
+}//OsDependent::initApiServer
 
 void
 OsDependent::setDefaultWindowAttributes (QWidget *pWidget)
@@ -362,7 +417,7 @@ OsDependent::getMainQML ()
 #if defined(MEEGO_HARMATTAN)
     return "qrc:/HMain.qml";
 #else
-    if (USE_QT_COMPONENTS && isSymbian3()) {
+    if (isSymbian3()) {
         return "qrc:/S3Main.qml";
     } else {
         return "qrc:/Main.qml";
